AccessToken

Struct AccessToken 

pub struct AccessToken(String);
Available on crate feature gitlab only.
Access token returned by the token endpoint and used to access protected resources.

Tuple Fields

0: String

Implementations



impl AccessToken

pub fn new(s: String) -> AccessToken

Create a new AccessToken to wrap the given String.

pub fn secret(&self) -> &String

Get the secret contained within this AccessToken.

Security Warning

Leaking this value may compromise the security of the OAuth2 flow.

pub fn into_secret(self) -> String

Get the secret contained within this AccessToken.

Security Warning

Leaking this value may compromise the security of the OAuth2 flow.